# 분산을 정리하는 대화

**학생**: 금새 끝났네요. 제 생각에는 너무 빨랐던 것 같아요!

> **교수**: 그래, 분산 시스템은 복잡하고 멋질 뿐만 아니라 공부할 만한 주제이지. 그렇지만 이 책에서 다룰 내용은 아니야 (또는 이과목에서).

**학생**: 안타깝네요. 저는 좀 더 배우고 싶어요! 뭔가 배운 것은 있어요.

> **교수**: 무엇을 배웠니?

**학생**: 그건요, 뭐든지 실패할 수 있다는 것이죠.

> **교수**: 시작이 좋구나.

**학생**: 그렇지만 이런 것들 (디스크가 되었든 기계나 다른 것이든)을 많이 갖고 있으면 발생하게 되는 많은 실패들을 감출 수 있어요.

> **교수**: 계속 해보렴!

**학생**: 기본적인 기술이기는 하지만 재시도하는 것도 매우 유용하고요.

> **교수**: 맞는 말이지.

**학생**: 기계들 간의 정확한 비트들을 교환하기 위해 사용하는 프로토콜에 대해서도 신중하게 생각을 해야 해요. 프로토콜들이 모든 것에 영향을 주죠. 시스템이 실패에 어떻게 반응하는지와 확장성의 정도 등에도 영향을 줘요.

> **교수**: 이제 배우는 것에 익숙해졌구나.

**학생**: 감사합니다! 그리고 교수님도 정말 잘 가르치십니다!

> **교수**: 그래, 정말 고맙구나.

**학생**: 이것으로 이 책이 다 끝나는 건가요?

> **교수**: 글쎄다. 특별한 말이 없구나.

**학생**: 저도 마찬가지에요. 이제 일어날까요.

> **교수**: 그러자꾸나.

**학생**: 먼저 가시죠.

> **교수**: 아닐세, 자네가 먼저 가게.

**학생**: 제발요, 교수님 먼저 가세요.

> **교수**: 아니야, 자네 다음에 가겠네.

**학생**: (짜증을 내며) 좋아요!

> **교수**: (기다리며) ... 아직 안 떠났나?

**학생**: 어떻게 가야할지 모르겠어요. 제가 할 수 있는게 이 대화에 참여하는 것 외에는 없는걸요.

> **교수**: 나도 마찬가질세. 이제 우리의 마지막 레슨까지 배웠네...
